from json.decoder import JSONDecodeError
import requests
import json
import os
from urllib.parse import urlencode
from .exceptions import  PushoverSenderException

config = dict()
config['pushover_api_url'] = os.environ['PUSHOVER_API_URL'] if 'PUSHOVER_API_URL' in os.environ else 'https://api.pushover.net/1/messages.json'
config['pushover_token'] = os.environ['PUSHOVER_TOKEN'] if 'PUSHOVER_TOKEN' in os.environ else None
config['pushover_user'] = os.environ['PUSHOVER_USER'] if 'PUSHOVER_USER' in os.environ else None



def send(message):
	post_form = urlencode({
		"token": config['pushover_token'],
		"user": config['pushover_user'],
		"message": message
	})
	if config['pushover_user'] is None or config['pushover_token'] is None:
		raise PushoverSenderException(message="PUSHOVER_USER and PUSHOVER_TOKEN environment variables must be set.")
	try:
		response = requests.post(config['pushover_api_url'], headers={'Content-type': 'application/x-www-form-urlencoded'}, data=post_form)
	except Exception as e:
		raise PushoverSenderException(message="Failed to perform Pushover API request: %s" % e)
	else:
		try:
			response_json = json.loads(response.text)
		except JSONDecodeError as e:
			response_json = None
		if response_json is None or 'status' not in response_json or response_json['status'] != 1:
			raise PushoverSenderException(message="Failed to send Pushover message. HTTP status: %d; message: %s" % (response.status_code, response.text))
